==> dev-plugin-android-7.0.7-beta5-sources.jar: com/zoyi/channel/plugin/android/selector/ChatSelector.java <==
package com.zoyi.channel.plugin.android.selector;

import android.support.annotation.Nullable;

import com.zoyi.channel.plugin.android.CHLocale;
import com.zoyi.channel.plugin.android.enumerate.FetchState;
import com.zoyi.channel.plugin.android.enumerate.SocketStatus;
import com.zoyi.channel.plugin.android.model.rest.SupportBotEntry;
import com.zoyi.channel.plugin.android.model.etc.Typing;
import com.zoyi.channel.plugin.android.model.rest.*;
import com.zoyi.channel.plugin.android.store.*;
import com.zoyi.channel.plugin.android.store.binder.*;
import com.zoyi.channel.plugin.android.store.state.*;
import com.zoyi.channel.plugin.android.util.CompareUtils;
import com.zoyi.channel.plugin.android.util.MessageUtils;
import com.zoyi.rx.functions.*;

import java.util.*;

public class ChatSelector {

  public static Binder bindWelcomeMessage(Action3<FetchState, SupportBotEntry, CharSequence> action3) {
    State<Plugin> pluginState = PluginStore.get().pluginState;
    State<FetchState> pluginFetchState = PluginStore.get().pluginFetchState;

    State<SupportBotEntry> supportBotState = SupportBotStore.get().supportBotState;
    State<FetchState> supportBotFetchState = SupportBotStore.get().supportBotFetchState;

    EnumState<CHLocale> localeState = SettingsStore.get().locale;

    return new Binder5<>(
        pluginState,
        pluginFetchState,
        supportBotState,
        supportBotFetchState,
        localeState
    ).bind((plugin, pluginFetch, supportBotEntry, supportBotFetch, locale) -> {
      if (supportBotFetch != FetchState.COMPLETE) {
        action3.call(supportBotFetch, null, null);
        return;
      }
      if (supportBotEntry != null) {
        action3.call(FetchState.COMPLETE, supportBotEntry, null);
        return;
      }
      if (pluginFetch != FetchState.COMPLETE) {
        action3.call(pluginFetch, null, null);
        return;
      }
      if (plugin != null) {
        action3.call(FetchState.COMPLETE, null, MessageUtils.createWelcomeMessage(plugin, locale));
        return;
      }
      action3.call(FetchState.FAILED, null, null);
    });
  }

  public static Binder bindChat(@Nullable String chatId, Action4<UserChat, Message, Boolean, Boolean> action4) {
    EntityMapState<UserChat> userChatsState = UserChatStore.get().userChats;
    State<Channel> channelState = ChannelStore.get().channelState;
    BooleanState typingState = TypingStore.get().typingState;
    State<Long> nowState = TimerStore.get().now;
    BooleanState temporaryInputOpenedState = ChatStore.get().temporaryInputOpenedState;
    MapState<String, Message> messageState = UserChatStore.get().messages;

    return new Binder6<>(userChatsState, channelState, typingState, nowState, temporaryInputOpenedState, messageState).bind(
        (userChats, channel, isTyping, now, temporaryInputOpened, messages) -> {
          if (userChats.containsKey(chatId) && userChats.get(chatId) != null) {
            action4.call(
                userChats.get(chatId),
                messages.get(chatId),
                ChannelSelector.shouldAcceptAction(channel, now, isTyping),
                temporaryInputOpened
            );
          }
        });
  }

  public static Binder bindTyping(Action1<Boolean> action1) {
    EnumState<SocketStatus> socketStatusState = SocketStore.get().socketState;
    ExpirableEntityMapState<Typing> myTypingState = TypingStore.get().myTypingState;

    return new Binder2<>(socketStatusState, myTypingState).bind((socketStatus, myTyping) -> {
      if (socketStatus == SocketStatus.READY) {
        action1.call(myTyping != null && myTyping.size() > 0);
      }
    });
  }

  public static Binder bindHostTyping(String chatId, Action1<List<Typing>> action1) {
    ExpirableEntityMapState<Typing> hostTypingState = TypingStore.get().hostTypingState;

    return new Binder1<>(hostTypingState).bind(typingMap -> {
      List<Typing> typings = new ArrayList<>();

      for (Typing typing : typingMap.values()) {
        if (typing != null && typing.getChatId() != null && typing.getChatId().equals(chatId)) {
          typings.add(typing);
        }
      }

      Collections.sort(typings, (o1, o2) -> CompareUtils.compare(o1.getCreatedAt(), o2.getCreatedAt()));

      action1.call(typings);
    });
  }
}

==> dev-plugin-android-7.1.1-beta5-sources.jar: com/zoyi/channel/plugin/android/selector/ChatSelector.java <==
package com.zoyi.channel.plugin.android.selector;

import android.support.annotation.Nullable;

import com.zoyi.channel.plugin.android.CHLocale;
import com.zoyi.channel.plugin.android.enumerate.FetchState;
import com.zoyi.channel.plugin.android.enumerate.SocketStatus;
import com.zoyi.channel.plugin.android.model.etc.Typing;
import com.zoyi.channel.plugin.android.model.rest.*;
import com.zoyi.channel.plugin.android.store.*;
import com.zoyi.channel.plugin.android.store.binder.*;
import com.zoyi.channel.plugin.android.store.state.*;
import com.zoyi.channel.plugin.android.util.*;
import com.zoyi.rx.functions.*;

import java.util.*;

public class ChatSelector {

  public static Binder bindWelcomeMessage(Action3<FetchState, SupportBotEntry, CharSequence> action3) {
    State<Plugin> pluginState = PluginStore.get().pluginState;
    State<FetchState> pluginFetchState = PluginStore.get().pluginFetchState;

    State<SupportBotEntry> supportBotState = SupportBotStore.get().supportBotState;
    State<FetchState> supportBotFetchState = SupportBotStore.get().supportBotFetchState;

    EnumState<CHLocale> localeState = SettingsStore.get().locale;

    return new Binder5<>(
        pluginState,
        pluginFetchState,
        supportBotState,
        supportBotFetchState,
        localeState
    ).bind((plugin, pluginFetch, supportBotEntry, supportBotFetch, locale) -> {
      if (supportBotFetch != FetchState.COMPLETE) {
        action3.call(supportBotFetch, null, null);
        return;
      }
      if (supportBotEntry != null) {
        action3.call(FetchState.COMPLETE, supportBotEntry, null);
        return;
      }
      if (pluginFetch != FetchState.COMPLETE) {
        action3.call(pluginFetch, null, null);
        return;
      }
      if (plugin != null) {
        action3.call(FetchState.COMPLETE, null, MessageUtils.createWelcomeMessage(plugin, locale));
        return;
      }
      action3.call(FetchState.FAILED, null, null);
    });
  }

  public static Binder bindChat(@Nullable String chatId, Action5<UserChat, Message, Boolean, Boolean, Boolean> action5) {
    EntityMapState<UserChat> userChatsState = UserChatStore.get().userChats;
    State<Channel> channelState = ChannelStore.get().channelState;
    BooleanState typingState = TypingStore.get().typingState;
    State<Long> nowState = TimerStore.get().now;
    BooleanState temporaryInputOpenedState = ChatStore.get().temporaryInputOpenedState;
    MapState<String, Message> messageState = UserChatStore.get().messages;

    return new Binder6<>(userChatsState, channelState, typingState, nowState, temporaryInputOpenedState, messageState).bind(
        (userChats, channel, isTyping, now, temporaryInputOpened, messages) -> {
          if (userChats.containsKey(chatId) && userChats.get(chatId) != null) {
            action5.call(
                userChats.get(chatId),
                messages.get(chatId),
                ChannelSelector.shouldAcceptAction(channel, now, isTyping),
                temporaryInputOpened,
                ChannelUtils.isWorking(channel, now)
            );
          }
        });
  }

  public static Binder bindTyping(Action1<Boolean> action1) {
    EnumState<SocketStatus> socketStatusState = SocketStore.get().socketState;
    ExpirableEntityMapState<Typing> myTypingState = TypingStore.get().myTypingState;

    return new Binder2<>(socketStatusState, myTypingState).bind((socketStatus, myTyping) -> {
      if (socketStatus == SocketStatus.READY) {
        action1.call(myTyping != null && myTyping.size() > 0);
      }
    });
  }

  public static Binder bindHostTyping(String chatId, Action1<List<Typing>> action1) {
    ExpirableEntityMapState<Typing> hostTypingState = TypingStore.get().hostTypingState;

    return new Binder1<>(hostTypingState).bind(typingMap -> {
      List<Typing> typings = new ArrayList<>();

      for (Typing typing : typingMap.values()) {
        if (typing != null && typing.getChatId() != null && typing.getChatId().equals(chatId)) {
          typings.add(typing);
        }
      }

      Collections.sort(typings, (o1, o2) -> CompareUtils.compare(o1.getCreatedAt(), o2.getCreatedAt()));

      action1.call(typings);
    });
  }
}
